@@ -27,7 +27,7 @@
 
     PyScriptTools Library
     =====================
-    version : 4.3.10\n
+    version : 4.3.12\n
     author : Shervin Badanara\n
     author github : https://www.github.com/shervinbdndev/\n
     source github : https://www.github.com/shervinbdndev/PyScriptTools.py/\n
@@ -48,12 +48,13 @@ try:
     from pathlib import Path
     
     from .base import *
+    from .utils import *
     from .tools import *
     from .validators import *
     from .exceptions import *
 
-except:
-    pass
+except ModuleNotFoundError.__doc__ as mnfe:
+    raise AttributeError(args='Cannot Run') from None
 
     
     
@@ -65,4 +66,4 @@ if (__name__ == '__main__' and __package__ is None):
     try:
         sys.path.remove(str(parent))
     except ValueError:
-        pass
\ No newline at end of file
+        raise BaseException.__doc__
\ No newline at end of file
